summaryrefslogtreecommitdiffstats
path: root/libk3b/tools/k3bintvalidator.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 19:21:21 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 19:21:21 +0000
commitd8cc8bdfa7fa624a526d5aa1626974e1444cb799 (patch)
treef295f1c545b319963d5357af79fe08991d8141d9 /libk3b/tools/k3bintvalidator.h
parent2a39a080579fb52a2599c02b2939795385b89093 (diff)
downloadk3b-d8cc8bdfa7fa624a526d5aa1626974e1444cb799.tar.gz
k3b-d8cc8bdfa7fa624a526d5aa1626974e1444cb799.zip
TQt4 port k3b
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k3b@1233803 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libk3b/tools/k3bintvalidator.h')
-rw-r--r--libk3b/tools/k3bintvalidator.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/libk3b/tools/k3bintvalidator.h b/libk3b/tools/k3bintvalidator.h
index 551d56a..0945f89 100644
--- a/libk3b/tools/k3bintvalidator.h
+++ b/libk3b/tools/k3bintvalidator.h
@@ -17,29 +17,29 @@
#ifndef _K3B_INT_VALIDATOR_H_
#define _K3B_INT_VALIDATOR_H_
-#include <qvalidator.h>
+#include <tqvalidator.h>
#include "k3b_export.h"
-class QWidget;
-class QString;
+class TQWidget;
+class TQString;
/**
* QValidator for integers.
*
- * It differs from QIntValidator and KIntValidator in the fact that
+ * It differs from TQIntValidator and KIntValidator in the fact that
* it also accepts hex numbers prefixed with 0x.
*/
-class LIBK3B_EXPORT K3bIntValidator : public QValidator
+class LIBK3B_EXPORT K3bIntValidator : public TQValidator
{
public:
/**
* Constuctor. Also sets the base value.
*/
- K3bIntValidator ( QWidget * parent, const char * name = 0 );
+ K3bIntValidator ( TQWidget * tqparent, const char * name = 0 );
/**
* Constructor. Also sets the minimum, maximum, and numeric base values.
*/
- K3bIntValidator ( int bottom, int top, QWidget * parent, const char * name = 0 );
+ K3bIntValidator ( int bottom, int top, TQWidget * tqparent, const char * name = 0 );
/**
* Destructs the validator.
@@ -49,12 +49,12 @@ class LIBK3B_EXPORT K3bIntValidator : public QValidator
/**
* Validates the text, and return the result. Does not modify the parameters.
*/
- virtual State validate ( QString &, int & ) const;
+ virtual State validate ( TQString &, int & ) const;
/**
* Fixes the text if possible, providing a valid string. The parameter may be modified.
*/
- virtual void fixup ( QString & ) const;
+ virtual void fixup ( TQString & ) const;
/**
* Sets the minimum and maximum values allowed.
@@ -74,7 +74,7 @@ class LIBK3B_EXPORT K3bIntValidator : public QValidator
/**
* If the string starts with 0x it's assumed to be a hex number.
*/
- static int toInt( const QString&, bool* ok = 0 );
+ static int toInt( const TQString&, bool* ok = 0 );
private:
int m_min;
@@ -17,29 +17,29 @@
/**
- * QValidator for integers.
+ * TQValidator for integers.
*